SystemOrganization addCategory: #'HelpSystem-Tests'!
SystemOrganization addCategory: 'HelpSystem-Tests-Builders'!
SystemOrganization addCategory: 'HelpSystem-Tests-Core-Model'!
SystemOrganization addCategory: 'HelpSystem-Tests-Core-UI'!
SystemOrganization addCategory: 'HelpSystem-Tests-Core-Utilities'!

TestCase subclass: #ClassAPIHelpBuilderTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'HelpSystem-Tests-Builders'!

!ClassAPIHelpBuilderTest commentStamp: 'TorstenBergmann 2/4/2014 21:18' prior: 0!
SUnit tests for ClassAPIHelpBuilder!

!ClassAPIHelpBuilderTest methodsFor: 'testing' stamp: 'LaurentLaffont 9/2/2010 15:55'!
testBuildingTraits
	|topic|
	topic := ClassAPIHelpBuilder 
				buildHelpTopicFrom: TSortable .				 
	self assert: topic subtopics size = 2.
	self assert: topic subtopics first title = 'Instance side'.
	self assert: topic subtopics last title = 'Class side'
 

 ! !

!ClassAPIHelpBuilderTest methodsFor: 'testing' stamp: 'tbn 3/8/2010 16:33'!
testDefaultBuilding
	|topic|
	topic := ClassAPIHelpBuilder 
				buildHelpTopicFrom: Integer.				 
	self assert: topic subtopics size = 2.
	self assert: topic subtopics first title = 'Instance side'.
	self assert: topic subtopics last title = 'Class side'
 

 ! !

!ClassAPIHelpBuilderTest methodsFor: 'testing' stamp: 'tbn 3/8/2010 16:32'!
testMethodsButNoSubclasses
	|topic|
	topic := ClassAPIHelpBuilder 
				buildHierarchicalHelpTopicFrom: Integer 
				withSubclasses: false 
				withMethods: true.
	self assert: topic subtopics size = 2.
	self assert: topic subtopics first title = 'Instance side'.
	self assert: topic subtopics last title = 'Class side'
 

 ! !

TestCase subclass: #CustomHelpTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'HelpSystem-Tests-Core-Utilities'!

!CustomHelpTest commentStamp: 'TorstenBergmann 2/4/2014 21:18' prior: 0!
SUnit tests for class CustomHelp
!

!CustomHelpTest methodsFor: 'testing' stamp: 'CamilloBruni 8/31/2013 20:26'!
testOpenBrowserOnThisHelpType

	|browser|
	browser := 	HelpBrowser openOn: CustomHelp.
	World doOneCycleNow. 
	browser close! !

TestCase subclass: #HelpBrowserTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'HelpSystem-Tests-Core-UI'!

!HelpBrowserTest commentStamp: 'TorstenBergmann 2/4/2014 21:18' prior: 0!
SUnit tests for the help browser!

!HelpBrowserTest methodsFor: 'accessing' stamp: 'tbn 5/3/2010 19:35'!
defaultTestClass
	^HelpBrowser! !

!HelpBrowserTest methodsFor: 'testing' stamp: 'tbn 5/3/2010 20:22'!
testDefaultHelpBrowser
	
	| current replacement instance |
	current := self defaultTestClass defaultHelpBrowser.
	replacement := AdvancedHelpBrowserDummy.
	[
	  self defaultTestClass defaultHelpBrowser: replacement.
	  self assert: self defaultTestClass defaultHelpBrowser == replacement.
 
	  instance := self defaultTestClass open.
	  self assert: instance rootTopic notNil.
	  self assert: instance isOpen.
	] ensure: [ self defaultTestClass defaultHelpBrowser: current ]
	 ! !

!HelpBrowserTest methodsFor: 'testing' stamp: 'tbn 5/3/2010 19:28'!
testDefaultHelpBrowserIsReplacable
	
	| current replacement instance |
	"save the one that is registered"
	current := self defaultTestClass defaultHelpBrowser.
	replacement := AdvancedHelpBrowserDummy.
	[
	  self defaultTestClass defaultHelpBrowser: replacement.
	  self assert: self defaultTestClass defaultHelpBrowser == replacement.	  
	  instance := self defaultTestClass open.
	  
	] ensure: [
		self defaultTestClass defaultHelpBrowser: current
	]
	 ! !

!HelpBrowserTest methodsFor: 'testing' stamp: 'tbn 5/3/2010 18:43'!
testLazyDefaultHelpBrowser
	
	self assert: self defaultTestClass defaultHelpBrowser notNil! !

!HelpBrowserTest methodsFor: 'testing' stamp: 'CamilloBruni 8/31/2013 20:33'!
testOpen
	|browser|
	browser := self defaultTestClass open.
	World doOneCycleNow. 
	browser close 


		! !

TestCase subclass: #HelpIconsTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'HelpSystem-Tests-Core-UI'!

!HelpIconsTest commentStamp: 'TorstenBergmann 2/4/2014 21:19' prior: 0!
SUnit tests for the icons used in the help system!

!HelpIconsTest methodsFor: 'accessing' stamp: 'tbn 2/12/2010 14:23'!
defaultTestClass 
	^HelpIcons! !

!HelpIconsTest methodsFor: 'testing' stamp: 'tbn 3/3/2010 00:50'!
testIconCaching
	 
	| first second |
	#(bookIcon pageIcon refreshIcon) do: [:iconSymbol |
		first := self defaultTestClass iconNamed: iconSymbol.
		second := self defaultTestClass iconNamed: iconSymbol.	
		self assert: first notNil.
		self assert: first == second.
	]
	! !

TestCase subclass: #HelpTopicListItemWrapperTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'HelpSystem-Tests-Core-UI'!

!HelpTopicListItemWrapperTest commentStamp: 'TorstenBergmann 2/4/2014 21:19' prior: 0!
SUnit tests for class HelpTopicListItemWrapper!

!HelpTopicListItemWrapperTest methodsFor: 'accessing' stamp: 'tbn 2/12/2010 13:16'!
defaultTestClass 
	^HelpTopicListItemWrapper 
	! !

!HelpTopicListItemWrapperTest methodsFor: 'testing' stamp: 'tbn 3/5/2010 21:46'!
testDisplayLabel
	|instance|
	instance := self defaultTestClass with: (HelpTopic named: 'My Topic').
	self assert: instance asString = 'My Topic'
	! !

TestCase subclass: #HelpTopicTest
	instanceVariableNames: 'topic'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'HelpSystem-Tests-Core-Model'!

!HelpTopicTest commentStamp: 'TorstenBergmann 2/4/2014 21:19' prior: 0!
SUnit tests for HelpTopic class!

!HelpTopicTest methodsFor: 'accessing' stamp: 'tbn 3/5/2010 21:47'!
defaultTestClass
	^HelpTopic ! !

!HelpTopicTest methodsFor: 'running' stamp: 'tbn 3/5/2010 21:49'!
setUp
	super setUp.
	topic := self defaultTestClass new.! !

!HelpTopicTest methodsFor: 'testing' stamp: 'tbn 3/8/2010 16:44'!
testAddingSubtopic

	|subtopic returned|
	subtopic := self defaultTestClass named: 'Subtopic'.
	returned := topic addSubtopic: subtopic.
	self assert: returned == subtopic.
	self assert: (topic subtopics includes: subtopic) ! !

!HelpTopicTest methodsFor: 'testing' stamp: 'tbn 3/6/2010 00:07'!
testInitialization

	self assert: topic title = 'Unnamed Topic'.
	self assert: topic key isEmpty.
	self assert: topic contents isEmpty ! !

!HelpTopicTest methodsFor: 'testing' stamp: 'tbn 3/6/2010 00:06'!
testInstanceCreation

	|instance|
	instance := self defaultTestClass named: 'My Topic'.
	self assert: instance title = 'My Topic'.
! !

!HelpTopicTest methodsFor: 'testing' stamp: 'tbn 3/6/2010 00:06'!
testSortOrder

	|a b c sorted |
	a := self defaultTestClass named: 'A'.
	b := self defaultTestClass named: 'B'.
	c := self defaultTestClass named: 'C'.
	sorted := (OrderedCollection with: b with: c with: a) asSortedCollection.
	self assert: sorted first = a.
	self assert: sorted last = c.
	! !

!HelpTopicTest methodsFor: 'testing' stamp: 'kilonalios 9/22/2013 17:56'!
testSubtopicOwnership
"Test that when a subtopic is added to a topic then owner of the subtopic is the topic"
	|subtopic owner|
	owner := self defaultTestClass named:  'I am the owner'.
	subtopic := self defaultTestClass named: 'I am the subtopic'.
	
	owner addSubtopic: subtopic.
	
	self assert: (subtopic owner == owner).
! !

TestCase subclass: #WikiStyleHelpBuilderTest
	instanceVariableNames: 'builder'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'HelpSystem-Tests-Builders'!

!WikiStyleHelpBuilderTest commentStamp: 'TorstenBergmann 2/4/2014 21:19' prior: 0!
SUnit tests for class WikiStyleHelpBuilder!

!WikiStyleHelpBuilderTest methodsFor: 'accessing' stamp: 'tbn 1/14/2011 01:44'!
defaultTestClass
	^WikiStyleHelpBuilder! !

!WikiStyleHelpBuilderTest methodsFor: 'running' stamp: 'tbn 1/14/2011 01:44'!
setUp
	super setUp.
	builder := self defaultTestClass new! !

!WikiStyleHelpBuilderTest methodsFor: 'testing' stamp: 'tbn 1/14/2011 01:44'!
testDefaultSyntaxAlwaysPier
	self assert: builder defaultSyntax == #pier! !

!WikiStyleHelpBuilderTest methodsFor: 'testing' stamp: 'tbn 1/14/2011 01:47'!
testExtractHelpContentsFromMarkedString
	|content|
	content := builder extractHelpContentFromString: 'outer<help>inner</help>outer'.
	self assert: content = 'inner'.
	! !

TestCase subclass: #WikiStyleHelpTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'HelpSystem-Tests-Core-Utilities'!

!WikiStyleHelpTest commentStamp: 'TorstenBergmann 2/4/2014 21:20' prior: 0!
SUnit tests for WikiStyleHelp!

!WikiStyleHelpTest methodsFor: 'testing' stamp: 'CamilloBruni 8/31/2013 20:26'!
testOpenBrowserOnThisHelpType
	|browser|
	browser := 	HelpBrowser openOn: WikiStyleHelp.
	World doOneCycleNow. 
	browser close
! !

Object subclass: #AdvancedHelpBrowserDummy
	instanceVariableNames: 'rootTopic isOpen'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'HelpSystem-Tests-Core-UI'!

!AdvancedHelpBrowserDummy commentStamp: 'tbn 5/3/2010 19:30' prior: 0!
This is a dummy for a custom Help browser that can be registered as a replacement for the HelpBrowser class.

Instance Variables
	rootTopic:		<HelpTopic>

rootTopic
	- The root help topic
!

!AdvancedHelpBrowserDummy methodsFor: 'initialization' stamp: 'tbn 5/3/2010 19:34'!
initialize
	isOpen := false! !

!AdvancedHelpBrowserDummy methodsFor: 'testing' stamp: 'tbn 5/3/2010 19:32'!
isOpen
	^isOpen! !

!AdvancedHelpBrowserDummy methodsFor: 'mocking' stamp: 'tbn 5/3/2010 19:32'!
open
	isOpen := true! !

!AdvancedHelpBrowserDummy methodsFor: 'mocking' stamp: 'tbn 5/3/2010 19:33'!
rootTopic
	^rootTopic! !

!AdvancedHelpBrowserDummy methodsFor: 'mocking' stamp: 'tbn 5/3/2010 19:33'!
rootTopic: aTopic
	rootTopic := aTopic! !
